emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/ssh-deploy 3fbd479 013/173: Changed variable-name typo


From: Stefan Monnier
Subject: [elpa] externals/ssh-deploy 3fbd479 013/173: Changed variable-name typo explicity-save to explicit-save and updated README.
Date: Sat, 20 Oct 2018 10:36:22 -0400 (EDT)

branch: externals/ssh-deploy
commit 3fbd479d103f0dec8785f97f95218ca55b8a628c
Author: Christian Johansson <address@hidden>
Commit: Christian Johansson <address@hidden>

    Changed variable-name typo explicity-save to explicit-save and updated 
README.
---
 README.md     | 17 ++++++-----------
 ssh-deploy.el | 10 +++++-----
 2 files changed, 11 insertions(+), 16 deletions(-)

diff --git a/README.md b/README.md
index 5f1333a..861bdd8 100644
--- a/README.md
+++ b/README.md
@@ -17,23 +17,25 @@ This application is made by Christian Johansson 
<address@hidden> 2016 and is l
 
 ``` elisp
 ((nil . ((ssh-deploy-root-local . "/Users/username/Web/MySite/")
-(ssh-deploy-root-remote . "address@hidden:/MySite/")
-(ssh-deploy-on-explicity-save . t))))
+(ssh-deploy-root-remote . "address@hidden:/var/www/MySite/")
+(ssh-deploy-on-explicit-save . t))))
 ```
 
 * And add this to your *emacs-init-script*:
 
 ``` elisp
 ;; ssh-deploy - prefix = C-c C-z, u = upload, d = download, x = diff
-(add-to-list 'load-path "~/.emacs.d/ssh-deploy/")
+(add-to-list 'load-path "~/.emacs.d/ssh-deploy/") ;; Comment out this line if 
installed from MELPA
 (use-package ssh-deploy
   :config
-  (add-hook 'after-save-hook (lambda() (if ssh-deploy-on-explicity-save 
(ssh-deploy-upload-handler)) ))
+  (add-hook 'after-save-hook (lambda() (if ssh-deploy-on-explicit-save 
(ssh-deploy-upload-handler)) ))
   (global-set-key (kbd "C-c C-z u") (lambda() 
(interactive)(ssh-deploy-upload-handler) ))
   (global-set-key (kbd "C-c C-z d") (lambda() 
(interactive)(ssh-deploy-download-handler)(revert-buffer) ))
   (global-set-key (kbd "C-c C-z x") (lambda() 
(interactive)(ssh-deploy-diff-handler) )))
 ```
 
+You can remove the `add-to-list` line if you installed via `MELPA` repository.
+
 * Now when you save a file somewhere under the directory 
`/Users/username/Web/MySite/`, the script will launch and deploy the file with 
the remote server.
 * If you press `C-c C-z x` you will launch a `ediff` session showing 
differences between local file and remote file using `tramp`.
 * If you press `C-c C-z u` you will upload local file to remote host.
@@ -41,13 +43,6 @@ This application is made by Christian Johansson 
<address@hidden> 2016 and is l
 
 The above configuration uses the plugin `use-package` which I highly recommend.
 
-## Items TODO:
-
-* Add a message if remote contents has changed since last upload
-* Add support for specific SSH identity files
-* Add support for specific SSH ports
-* Add support for upload/download/diff of directories
-
 ## Read more
 * <https://www.emacswiki.org/emacs/DirectoryVariables>
 * <http://www.gnu.org/software/tramp/>
diff --git a/ssh-deploy.el b/ssh-deploy.el
index 9f826a8..2060909 100644
--- a/ssh-deploy.el
+++ b/ssh-deploy.el
@@ -3,8 +3,8 @@
 ;; Author: Christian Johansson <github.com/cjohansson>
 ;; Maintainer: Christian Johansson <github.com/cjohansson>
 ;; Created: 5 Jul 2016
-;; Modified: 11 Jul 2016
-;; Version: 1.0
+;; Modified: 15 Jul 2016
+;; Version: 1.1
 ;; Keywords: tools, convenience
 ;; URL: https://github.com/cjohansson/emacs-ssh-deploy
 
@@ -34,11 +34,11 @@
 ;; password-less authorized SSH connections.  To do this it uses tramp,
 ;; scp and ediff.  By setting the variables (globally or per directory):
 ;; `ssh-deploy-root-local`,`ssh-deploy-root-remote`,
 ;; `ssh-deploy-on-explicity-save` you can setup a directory for
 ;; SSH deploy.
 ;;
 ;; - To setup hook on explicit save do this:
-;;     (add-hook 'after-save-hook (lambda() (if ssh-deploy-on-explicity-save 
(ssh-deploy-upload-handler)) ))
+;;     (add-hook 'after-save-hook (lambda() (if ssh-deploy-on-explicit-save 
(ssh-deploy-upload-handler)) ))
 ;;
 ;; - To set key-bindings do something like this:
 ;;     (global-set-key (kbd "C-c C-z u") (lambda() 
(interactive)(ssh-deploy-upload-handler) ))
@@ -64,7 +64,7 @@
   :type 'string
   :group 'ssh-deploy)
 
-(defcustom ssh-deploy-on-explicity-save nil
+(defcustom ssh-deploy-on-explicit-save nil
   "Boolean variable if deploy should be made on explicit save, nil by default."
   :type 'boolean
   :group 'ssh-deploy)
@@ -34,11 +34,11 @@
 ;; scp and ediff.  By setting the variables (globally or per directory):
 ;; `ssh-deploy-root-local`,`ssh-deploy-root-remote`,
-;; `ssh-deploy-on-explicity-save` you can setup a directory for
+;; `ssh-deploy-on-explicit-save` you can setup a directory for
 ;; SSH deploy.
 ;;



reply via email to

[Prev in Thread] Current Thread [Next in Thread]